==> bigloo1.3b.tar.gz: bigloo1.3/comptime1.3/Heap/restore.scm <==
;*---------------------------------------------------------------------*/
;*    Copyright (c) 1993 by Manuel Serrano. All rights reserved.       */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \    /  '                              */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome Send them to                                           */
;*        <Manuel.Serrano@inria.fr>                                    */
;*        Manuel Serrano                                               */
;*        INRIA -- Rocquencourt                                        */
;*        Domaine de Voluceau, BP 105                                  */
;*        78153 Le Chesnay Cedex                                       */
;*        France                                                       */
;*---------------------------------------------------------------------*/


;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloo/comptime1.2/Heap/restore.scm ...     */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Tue Jun 23 17:04:32 1992                          */
;*    Last change :  Wed Mar 24 09:12:55 1993  (serrano)               */
;*                                                                     */
;*    On recharge un tas qui a ete construit par bigloo                */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module heap_restore
   (include "Var/variable.sch")
   (import  engine_param
	    tools_speek
	    heap_compact
	    heap_abstract
	    var_env)
   (export  (restore-heap)))

;*---------------------------------------------------------------------*/
;*    restore-heap ...                                                 */
;*---------------------------------------------------------------------*/
(define (restore-heap)
   (verbose "   . Heap" #\Newline)
   (if (string? *heap-name*)
       (let* ((port    (open-input-file *heap-name*))
	      (handler (lambda (escape proc mes obj)
			  (notify-error proc mes obj)
			  (input-port-display-error port (current-error-port))
			  (close-input-port port)
			  (exit -5))))
	  (if (not (input-port? port))
	      (error "restore-heap"
		     "Can't open heap file"
		     *heap-name*)
	      (try (let loop ((r (read port)))
		      (if (eof-object? r)
			  (begin
			     (abstract-init!)
			     ;; on a fini de restorer la librairie. On 
			     ;; supprime eventuellement la fonction call/cc.
			     (if (and (not *call/cc?*)
				      (not *lib-mode*))
				 (let ((callcc (find-in-global-environment
						'call/cc *Genv*)))
				    (if (and (global? callcc)
					     (eq? (global-module callcc)
						  '__R4_CONTROL_FEATURES_6_9))
					(unbind-in-global-environment!
					 'call/cc *Genv*))))
			     (close-input-port port))
			  (let ((name (vector-ref r 1)))
			     (uncompact! r)
			     (loop (read port)))))
		   handler)))))

==> bigloo_1.8b.orig.tar.gz: bigloo-1.8b.orig/comptime1.8/Heap/restore.scm <==
;*---------------------------------------------------------------------*/
;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \    /  '                              */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome Send them to                                           */
;*        <Manuel.Serrano@inria.fr>                                    */
;*        Manuel Serrano                                               */
;*        INRIA -- Rocquencourt                                        */
;*        Domaine de Voluceau, BP 105                                  */
;*        78153 Le Chesnay Cedex                                       */
;*        France                                                       */
;*---------------------------------------------------------------------*/


;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime1.8/Heap/restore.scm         */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Mon Dec 26 10:53:23 1994                          */
;*    Last change :  Mon Mar 11 13:58:49 1996 (serrano)                */
;*    -------------------------------------------------------------    */
;*    We restore an heap                                               */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module heap_restore
   (include "Tools/pass.sch")
   (export  (restore-heap))
   (import  engine_param
	    engine_engine
	    main
	    tools_file
	    tools_error
	    ast_env
	    type_env))

;*---------------------------------------------------------------------*/
;*    restore-heap ...                                                 */
;*---------------------------------------------------------------------*/
(define (restore-heap)
   (if (string? *heap-name*)
       (begin
	  (pass-prelude "Heap")
	  (let ((fname (find-file/path *heap-name* (list *lib-dir*))))
	     (if (string? fname)
 		 (let* ((port    (open-input-binary-file fname))
			(handler (lambda (escape proc mes obj)
				    (notify-error proc mes obj)
				    (close-binary-port port)
				    (exit-bigloo -5))))
		    (if (not (binary-port? port))
			(begin
			   (error "restore-heap" "Cannot open heap file" fname)
			   (exit-bigloo -5))
			(try (let* ((Envs (input-obj port))
				    (Genv (car Envs))
				    (Tenv (cdr Envs)))
				(close-binary-port port)
				(set-Genv! Genv)
				(set-Tenv! Tenv)
				(if (not *call/cc?*) (unbind-call/cc!))
				#t)
			     handler)))
		 (begin
		    (error "restore-heap" "Cannot find heap file" *heap-name*)
		    (exit-bigloo -5)))))
       #f))

;*---------------------------------------------------------------------*/
;*    unbind-call/cc! ...                                              */
;*---------------------------------------------------------------------*/
(define (unbind-call/cc!)
   (if (find-global 'call/cc '__r4_control_features_6_9)
       (unbind-global! 'call/cc '__r4_control_features_6_9)))
